Documentation
¶
Overview ¶
Package to read and write FASTA format files
Index ¶
Constants ¶
This section is empty.
Variables ¶
var ( IDPrefix = []byte(">") // default delimiters SeqPrefix = []byte("") // default delimiters )
Functions ¶
Types ¶
type Reader ¶
Fasta sequence format reader type.
func NewReaderName ¶
Returns a new fasta format reader using a filename.
type Writer ¶
type Writer struct {
IDPrefix string
SeqPrefix string
Width int
// contains filtered or unexported fields
}
Fasta sequence format writer type.
func NewWriter ¶
func NewWriter(f io.WriteCloser, width int) *Writer
Returns a new fasta format writer using f.
func NewWriterName ¶
Returns a new fasta format writer using a filename, truncating any existing file. If appending is required use NewWriter and os.OpenFile.
Click to show internal directories.
Click to hide internal directories.